import { EquipmentSlot, world, BlockPermutation, system } from "@minecraft/server";
import { ActionFormData, ModalFormData, MessageFormData } from "@minecraft/server-ui";


world.beforeEvents.playerInteractWithBlock.subscribe((event) => {
    const { block, dimension, player } = event;
    const alphaSizeState = block.permutation.getState("mrki:alpha_size");
    if (player.isSneaking) return;

    if (alphaSizeState !== undefined) {
        if (!player) return;
        const equippable = player.getComponent("minecraft:equippable");
        if (!equippable) {
            return;
        }
        const mainhand = equippable.getEquipmentSlot(EquipmentSlot.Mainhand);
        if (!mainhand.hasItem() || mainhand.typeId !== "mrki_ab:alphabet_wand") {
            return;
        }
        system.runTimeout(() => {
            const blockPermutation = block.permutation;
            const currentSize = blockPermutation.getState("mrki:alpha_size");
            const newSize = (currentSize + 1) % 2;
            const location = block.location;
            if (newSize == 1) { player.runCommandAsync(`particle mrki_ab:block_resize_particle ${location.x} ${location.y} ${location.z}`); player.runCommandAsync(`playsound block.itemframe.remove_item`); }
            block.setPermutation(
                block.permutation.withState("mrki:alpha_size", newSize)
            );

        }, 1);
    }
});
world.beforeEvents.worldInitialize.subscribe(({ blockComponentRegistry }) => {
    blockComponentRegistry.registerCustomComponent(
        "mrki:alpha_size",
        CustomBlockComponent
    );
    blockComponentRegistry.registerCustomComponent(
        "mrki:on_place",
        CustomBlockOnPlace
    );
});
const CustomBlockComponent = {
    onStepOn({ entity }) {
        if (entity) return;

    }

};
const CustomBlockOnPlace = {
    beforeOnPlayerPlace(event) {
        const player = event.player
        player.runCommandAsync(`playsound mrki_ab:workbench_place_1 @s ~ ~ ~ 0.5`)
        player.runCommandAsync(`playsound mrki_ab:workbench_place_2 @s ~ ~ ~ 0.5`)
        player.runCommandAsync(`tag @s add sound`)
    },
    onPlace(event) {
        const block = event.block
        const dimension = event.dimension
        const location = block.location;
        dimension.runCommandAsync(`summon mrki_ab:workbench_particles ${location.x} ${location.y} ${location.z}`)

    },
    onPlayerDestroy(event) {
        const block = event.block
        const dimension = event.dimension
        const location = block.location;
        const player = event.player;
        dimension.runCommandAsync(`/event entity @e[type=mrki_ab:workbench_particles,x=${location.x},y=${location.y},z=${location.z}] mrki:despawn`)
        dimension.runCommandAsync(`/stopsound @p[x=${location.x},y=${location.y},z=${location.z},r=5,tag=sound] mrki_ab:workbench_place_1`)
        dimension.runCommandAsync(`/stopsound @p[x=${location.x},y=${location.y},z=${location.z},r=5,tag=sound] mrki_ab:workbench_place_2`)
        dimension.runCommandAsync(`/tag @p[x=${location.x},y=${location.y},z=${location.z},r=5,tag=sound] remove tag`)
    }
};

